ASTExprOpType

Enum ASTExprOpType 

pub enum ASTExprOpType {
Show 27 variants Error, And, AndThen, Or, OrElse, Max, Min, Minus, Add, Sub, Mul, Div, FdivQ, PdivQ, PdivR, ZdivR, Cond, Select, Eq, Le, Lt, Ge, Gt, Call, Access, Member, AddressOf,
}

Variants



Error



And



AndThen



Or



OrElse



Max



Min



Minus



Add



Sub



Mul



Div



FdivQ



PdivQ



PdivR



ZdivR



Cond



Select



Eq



Le



Lt



Ge



Gt



Call



Access



Member



AddressOf

Implementations

Source

impl ASTExprOpType

pub fn to_i32(&self) -> i32

Returns i32 values as defined in libisl.

Source

impl ASTExprOpType

pub fn from_i32(val: i32) -> Self

Constructor based on the i32 values as defined in libisl.